==> ejc-procurement-api-3.0.0-20251215.092516-126-sources.jar: com/ejianc/business/procurement/perform/vo/ExpertExtractionMemberVO.java <==
package com.ejianc.business.procurement.perform.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 专家抽取记录-评标委员会情况
 *
 * @author generator
 *
 */
public class ExpertExtractionMemberVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String bodyMemo; // 备注
    private Integer industryType; // 行业类型
    private Integer enterFlag; // 确认是否参加
    private String telephone; // 联系电话
    private String workOrg; // 工作单位
    private Long pid; // 主表主键
    private Integer inStore; // 是否在库
    private String memberType; // 人员类型
    private String memberName; // 姓名
    private String memberCode; // 员工编码
    private Long memberId; // 员工id
    private String idCard; // 证件号码

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getBodyMemo() {
        return bodyMemo;
    }

    public void setBodyMemo(String bodyMemo) {
        this.bodyMemo = bodyMemo;
    }

    public Integer getIndustryType() {
        return industryType;
    }

    public void setIndustryType(Integer industryType) {
        this.industryType = industryType;
    }

    public Integer getEnterFlag() {
        return enterFlag;
    }

    public void setEnterFlag(Integer enterFlag) {
        this.enterFlag = enterFlag;
    }

    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    public String getWorkOrg() {
        return workOrg;
    }

    public void setWorkOrg(String workOrg) {
        this.workOrg = workOrg;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Integer getInStore() {
        return inStore;
    }

    public void setInStore(Integer inStore) {
        this.inStore = inStore;
    }

    public String getMemberType() {
        return memberType;
    }

    public void setMemberType(String memberType) {
        this.memberType = memberType;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Long getMemberId() {
        return memberId;
    }

    public void setMemberId(Long memberId) {
        this.memberId = memberId;
    }

}

==> ejc-procurement-api-3.0.0-20251216.072949-134-sources.jar: com/ejianc/business/procurement/perform/vo/ExpertExtractionMemberVO.java <==
package com.ejianc.business.procurement.perform.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 专家抽取记录-评标委员会情况
 *
 * @author generator
 *
 */
public class ExpertExtractionMemberVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String bodyMemo; // 备注
    private Integer industryType; // 行业类型
    private Integer enterFlag; // 确认是否参加
    private String telephone; // 联系电话
    private String workOrg; // 工作单位
    private Long pid; // 主表主键
    private Integer inStore; // 是否在库
    private String memberType; // 人员类型
    private String memberName; // 姓名
    private String memberCode; // 员工编码
    private Long memberId; // 员工id
    private String idCard; // 证件号码

    // 主表冗余
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date startDate; // 评标开始时间

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getBodyMemo() {
        return bodyMemo;
    }

    public void setBodyMemo(String bodyMemo) {
        this.bodyMemo = bodyMemo;
    }

    public Integer getIndustryType() {
        return industryType;
    }

    public void setIndustryType(Integer industryType) {
        this.industryType = industryType;
    }

    public Integer getEnterFlag() {
        return enterFlag;
    }

    public void setEnterFlag(Integer enterFlag) {
        this.enterFlag = enterFlag;
    }

    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    public String getWorkOrg() {
        return workOrg;
    }

    public void setWorkOrg(String workOrg) {
        this.workOrg = workOrg;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Integer getInStore() {
        return inStore;
    }

    public void setInStore(Integer inStore) {
        this.inStore = inStore;
    }

    public String getMemberType() {
        return memberType;
    }

    public void setMemberType(String memberType) {
        this.memberType = memberType;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Long getMemberId() {
        return memberId;
    }

    public void setMemberId(Long memberId) {
        this.memberId = memberId;
    }

}
